Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1107)

Unified Diff: media/midi/midi_manager_alsa.cc

Issue 2170463003: Web MIDI: Add CHECK()s to ensure MidiManager owned threads are terminated (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: review #11 Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/midi/midi_manager.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/midi/midi_manager_alsa.cc
diff --git a/media/midi/midi_manager_alsa.cc b/media/midi/midi_manager_alsa.cc
index 9dc0582e6a41cccff48e992a0d6f8852cff7e25f..a3c37b8b6ecee2e2e8c33ebcb79e886cf3e482c4 100644
--- a/media/midi/midi_manager_alsa.cc
+++ b/media/midi/midi_manager_alsa.cc
@@ -158,13 +158,16 @@ MidiManagerAlsa::~MidiManagerAlsa() {
// are not destructed here.
base::AutoLock lock(lazy_init_member_lock_);
- // Extra DCHECK to verify all members are already reset.
- DCHECK(!initialization_thread_checker_);
- DCHECK(!in_client_);
- DCHECK(!out_client_);
- DCHECK(!decoder_);
- DCHECK(!udev_);
- DCHECK(!udev_monitor_);
+ // Extra CHECK to verify all members are already reset.
+ CHECK(!initialization_thread_checker_);
+ CHECK(!in_client_);
+ CHECK(!out_client_);
+ CHECK(!decoder_);
+ CHECK(!udev_);
+ CHECK(!udev_monitor_);
+
+ CHECK(!send_thread_.IsRunning());
+ CHECK(!event_thread_.IsRunning());
}
void MidiManagerAlsa::StartInitialization() {
« no previous file with comments | « media/midi/midi_manager.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698